﻿namespace HierarchicalGrid.Model
{
    using System;
    using System.Collections.Generic;
    using System.Collections.ObjectModel;
    using System.ComponentModel;
    using System.Globalization;

    public class Employee : INotifyPropertyChanged
    {
        
        #region INotifyPropertyChanged Members

        public event PropertyChangedEventHandler PropertyChanged;

        private void NotifyPropertyChanged(String info)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(info));
            }
        }

        #endregion

        private int employId;
        private string name;
        private bool onSite;
        private int departmentId;
        private string mobile;
        private string address1;
        private string address2;
        private string city;

        public Employee()
        {
            this.ReportingEmployees = new List<Employee>();
        }

        public int EmployId
        {
            get { return this.employId; }
            set
            {
                this.employId = value;
                NotifyPropertyChanged("EmployId");
            }
        }

        public string Name
        {
            get { return this.name; }
            set
            {
                this.name = value;
                NotifyPropertyChanged("Name");
            }
        }

        public bool OnSite
        {
            get { return this.onSite; }
            set
            {
                this.onSite = value;
                NotifyPropertyChanged("OnSite");
            }
        }

        public int DepartmentId
        {
            get { return this.departmentId; }
            set
            {
                this.departmentId = value;
                NotifyPropertyChanged("DepartmentId");
            }
        }

        public string Mobile
        {
            get { return this.mobile; }
            set
            {
                this.mobile = value;
                NotifyPropertyChanged("Mobile");
            }
        }

        public string Address1
        {
            get { return this.address1; }
            set
            {
                this.address1 = value;
                this.NotifyPropertyChanged("Address1");
            }
        }

        public string Address2
        {
            get { return this.address2; }
            set
            {
                this.address2 = value;
                this.NotifyPropertyChanged("Address2");
            }
        }

        public string City
        {
            get { return this.city; }
            set
            {
                this.city = value;
                this.NotifyPropertyChanged("City");
            }
        }

        private string postCode;

        public string PostCode
        {
            get { return this.postCode; }
            set
            {
                this.postCode = value;
                this.NotifyPropertyChanged("PostCode");
            }
        }

        public List<Employee> ReportingEmployees { get; set; }
    }

    public static class Service
    {
        public static ObservableCollection<Employee> GetEmployees()
        {
            var employees = new ObservableCollection<Employee>();
            for (int i = 1; i <= 15; i++)
            {
                var employee = new Employee 
                { 
                    EmployId = i, 
                    Name = String.Format("Name {0}", i), 
                    DepartmentId = i % 4, 
                    OnSite = (i % 2 == 0), 
                    Mobile = "0123456789",
                    Address1 = "Address .... 1",
                    Address2  = "Address ..... 2",
                    City = "London",
                    PostCode = "AB5C 5DE"
                };
                if (i % 3 == 0)
                {
                    employee.ReportingEmployees.Add(new Employee 
                    { 
                        EmployId = i + 300,
                        Name = (i + 300).ToString(CultureInfo.InvariantCulture) + " Reporting to: " + employee.Name,
                        OnSite = employee.OnSite,
                        DepartmentId = i%3
                    });
                    employee.ReportingEmployees.Add(new Employee
                    {
                        EmployId = i + 301,
                        Name = (i + 301).ToString(CultureInfo.InvariantCulture) + " Reporting to: " + employee.Name,
                        OnSite = employee.OnSite,
                        DepartmentId = i % 3
                    });                    
                }
                employees.Add(employee);
            }
            return employees;
        }
    }
}
